@@ -2,7 +2,7 @@ from ..utils import EmbedFactory, MainMenu, get_bot_message
 
 from disnake import HTTPException, Message, MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
-from disnake.ext.commands import Context
+from disnake.ext.commands import Context, Bot
 
 
 class Change(View):
@@ -10,7 +10,7 @@ class Change(View):
         super().__init__()
 
         self.ctx = ctx
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
         self.add_item(MainMenu(ctx))
 
@@ -38,6 +38,8 @@ class Change(View):
             await interaction.message.reply(
                 "My username must be between `2-32` characters in length"
             )
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
 
         try:
             await self.bot.user.edit(username=message.content)
@@ -73,6 +75,9 @@ class Change(View):
         ).attachments:
             await interaction.message.reply("You must send an image file!")
 
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         try:
             await self.bot.user.edit(avatar=await message.attachments[0].read())
         except HTTPException:
