@@ -1,9 +1,7 @@
 import os
 import asyncio
 
-from ..utils import FindSnowflake, EmbedFactory, MainMenu, get_bot_message
-from ..constants import THUMBS_UP, ERROR
-
+from ..utils import EmbedFactory, MainMenu, get_bot_message
 from disnake import Message, MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
 from disnake.ext.commands import Context, Bot
