@@ -1,6 +1,4 @@
-import os
-
-from dotenv import load_dotenv
+from .constants import EMBED_COLOR
 from typing import Union, Optional
 from disnake import (
     ButtonStyle,
@@ -20,22 +18,6 @@ from disnake.ext.commands import Context, Bot
 newline = "\n"
 
 
-class InvalidEnv(Exception):
-    """ """
-
-
-try:
-    load_dotenv()
-    os.environ["EMBED_COLOR"]
-except KeyError:
-    with open("./.env", "a") as env:
-        env.write("\n#disnake-debug\nEMBED_COLOR = 0x0000ff")
-try:
-    EMBED_COLOR = int(os.environ["EMBED_COLOR"], 16)
-except (TypeError, ValueError):
-    raise InvalidEnv("EMBED_COLOR must be hex")
-
-
 def get_bot_message(ctx: Context) -> Message:
     return ctx.bot._bot_messages[ctx.message.id]
 
@@ -45,8 +27,7 @@ def clean_code(content: str):
         content = content[5:-3]
     content = content.strip("`")
     content = (
-        content.replace("‘", "'").replace(
-            "“", '"').replace("”", '"').replace("’", "'")
+        content.replace("‘", "'").replace("“", '"').replace("”", '"').replace("’", "'")
     )
     return content
 
@@ -54,8 +35,13 @@ def clean_code(content: str):
 class FindSnowflake:
     @staticmethod
     async def find_any(bot: Bot, query: str) -> Union[User, Guild, TextChannel, None]:
-        for method in [FindSnowflake.find_user, FindSnowflake.find_guild, FindSnowflake.find_channel, FindSnowflake.find_emoji]:
-            response = method(query)
+        for method in [
+            FindSnowflake.find_user,
+            FindSnowflake.find_guild,
+            FindSnowflake.find_channel,
+            FindSnowflake.find_emoji,
+        ]:
+            response = await method(bot, query)
             if response:
                 return response
 
@@ -120,17 +106,18 @@ class FindSnowflake:
                 _id = int(query)
             except ValueError:
                 try:
-                    _id = int(query.split(':')[-1][:-1])
+                    _id = int(query.split(":")[-1][:-1])
                     emoji = bot.get_emoji(_id)
                     if isinstance(emoji, Emoji):
                         return emoji
                 except ValueError:
                     pass
-           
+
         emoji = utils.get(bot.emojis, name=query)
         if emoji:
             return emoji
 
+
 class EmbedFactory:
     """Embed factory"""
 
@@ -172,17 +159,13 @@ class EmbedFactory:
         ctx: Context,
         reason: str,
     ) -> Embed:
-        return (
-            Embed(
-                title="Uh oh",
-                description=f"```yaml\n{reason}```",
-                timestamp=ctx.message.created_at,
-                colour=EMBED_COLOR
-            ).set_author(
-                name=ctx.author,
-                icon_url=ctx.author.avatar.url
-            )
-        )
+        return Embed(
+            title="Uh oh",
+            description=f"```yaml\n{reason}```",
+            timestamp=ctx.message.created_at,
+            colour=EMBED_COLOR,
+        ).set_author(name=ctx.author, icon_url=ctx.author.avatar.url)
+
 
 class MainMenu(Button):
     def __init__(self, ctx: Context):
